=============
TethysCluster
=============
:TethysCluster: Cloud Computing Toolkit for Diverse Clusters
:Version: 0.1.4
:Author: Scott Christensen
:Team: CI-Water
:Homepage: http://ci-water.github.io/TethysCluster/
:License: LGPL

Description:
============
TethysCluster is an adaptation of StarCluster with the goal of making it
compatible with multiple platforms and cloud providers including Windows
and Microsoft Azure.

StarCluster is a utility for creating and managing computing clusters hosted on
Amazon's Elastic Compute Cloud (EC2). StarCluster utilizes Amazon's EC2 web
service to create and destroy clusters of Linux virtual machines on demand.

For more information about the StarCluster project see https://star.mit.edu/cluster/


Licensing
=========
TethysCluster is licensed under the LGPLv3
See COPYING.LESSER (LGPL) and COPYING (GPL) for LICENSE details
